Option Explicit

'Declare API call needed to read the WIN.INI file
Declare Function KRN_GetProfileString Lib "Kernel" Alias "GetProfileString" (ByVal mSection As String, ByVal mEntry As String, ByVal mDefault As String, ByVal mReturnString As String, ByVal mReturnSize As Integer) As Integer

'   FUNCTION NAME:      Get_String
'     DESCRIPTION:      Searches the WIN.INI file sections and entries.  Returns the located value or the default value.
'          TABLES:      None
'           FILES:      WIN.INI file
'      PARAMETERS:      Section - section header name to search for
'                       Entry - variable name within the section to return
'                       Default - value to return if no section/entry is found
'
'                             MODIFICATION  HISTORY
'     DATE           CHANGE               BY
'    4/12/95         Created            Richard Hammer
'
Function Get_String (ByVal Section As String, ByVal Entry As String, ByVal Default As String) As String
    On Error GoTo Get_String_Error
    
    Dim RetVal As String
    Dim RetSize As Integer
    Dim ValSize As Integer
    
    If IsEmpty(Section) Or IsEmpty(Entry) Then
        Get_String = Default
    Else
        RetVal = Space$(512)
        RetSize = Len(RetVal)
        
        ValSize = KRN_GetProfileString(Section, Entry, Default, RetVal, RetSize)
        Get_String = Left$(RetVal, ValSize)
    End If
Exit Function

Get_String_Error:
    Get_String = Default
End Function

'   FUNCTION NAME:      Win_INI_Color
'     DESCRIPTION:      Searches the WIN.INI file for the specified section string then calculates and returns the Windows color specification.
'          TABLES:      None
'           FILES:      WIN.INI file
'      PARAMETERS:      Section - The valid WIN.INI sections are:
'                                   ActiveBorder        - Color of an active form or window border
'                                   ActiveTitle         - Color of an active form or window title, caption, or header field
'                                   AppWorkspace        - Color of a form or window field
'                                   Background          - Color of the windows workspace background, displayed when no wallpaper is selected
'                                   ButtonFace          - Color of the button face or field
'                                   ButtonHilight       - Color of the button hi-light (top-left part of 3-D)
'                                   ButtonShadow        - Color of the button shadow (bottom-right part of 3-D)
'                                   ButtonText          - Color of the text on the button
'                                   GrayText            - Color of the disabled menu text
'                                   Hilight             - Color of the hi-light bar in menu options
'                                   HilightText         - Color of the hi-light text in menu bar options
'                                   InactiveBorder      - Color of an inactive form or window border
'                                   InactiveTitle       - Color of an inactive form or window title, caption, or header field
'                                   InactiveTitleText   - Color of an inactive form or window title, caption, or header text
'                                   Menu                - Color of the menu bar
'                                   MenuText            - Color of the menu bar text
'                                   Scrollbar           - Color of the scrollbar indicator
'                                   TitleText           - Color of an active form or window title, caption, or header text
'                                   Window              - Color of an entry field or child form or window
'                                   WindowFrame         -
'                                   WindowText          - Color of the text in the entry field or child form or window
'                       Default - Used as the color selection when the WIN.INI value cannot be found or calculated
'
'                             MODIFICATION  HISTORY
'     DATE           CHANGE               BY               REASON FOR CHANGE
'   4/1/1995         Created            WIDRPH
'
Function Win_INI_Color (ByVal Section As String, ByVal Default) As Long
    On Error GoTo Win_INI_Color

    Dim Win_INI_Value As String

    Win_INI_Value = Get_String("Colors", Section, Default)
    If Win_INI_Value <> Default Then
        Win_INI_Color = Win2RGB(Win_INI_Value, Default)
    Else
        Win_INI_Color = CLng(Default)
    End If
Exit Function

Win_INI_Color:
    Win_INI_Color = CLng(Default)
End Function

'   FUNCTION NAME:      Win2RGB
'     DESCRIPTION:      Calculates the RGN value from the WIN.INI Color setting
'          TABLES:      None
'           FILES:      None
'      PARAMETERS:      Win_INI - Color value from the Win.INI.  i.e. "192 9 90"
'                       Default - Used as the color selection when the WIN.INI value cannot be found or calculated
'
'                             MODIFICATION  HISTORY
'     DATE           CHANGE               BY               REASON FOR CHANGE
'    4/1/95          Created            WIDRPH
'
Function Win2RGB (Win_INI As String, Default) As Long
    On Error GoTo Win2RGB
    
    Dim Red, Green, Blue
    Dim C_Pos1 As Integer
    Dim C_Pos2 As Integer
    
    C_Pos1 = InStr(1, Win_INI, " ")
    C_Pos2 = InStr(C_Pos1 + 1, Win_INI, " ")
    
    Red = Left(Win_INI, C_Pos1 - 1)
    Green = Mid(Win_INI, C_Pos1 + 1, C_Pos2 - C_Pos1)
    Blue = Mid(Win_INI, C_Pos2 + 1)

    Win2RGB = RGB(Red, Green, Blue)
Exit Function

Win2RGB:
    Win2RGB = CLng(Default)
End Function

